Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/facet/org.eclipse.papyrus.emf.facet.util.emf.catalog/src/org/eclipse/papyrus/emf/facet/util/emf/catalog/CatalogSet.java')
-rw-r--r--plugins/facet/org.eclipse.papyrus.emf.facet.util.emf.catalog/src/org/eclipse/papyrus/emf/facet/util/emf/catalog/CatalogSet.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/plugins/facet/org.eclipse.papyrus.emf.facet.util.emf.catalog/src/org/eclipse/papyrus/emf/facet/util/emf/catalog/CatalogSet.java b/plugins/facet/org.eclipse.papyrus.emf.facet.util.emf.catalog/src/org/eclipse/papyrus/emf/facet/util/emf/catalog/CatalogSet.java
index 54dab357c78..3c6bae05527 100644
--- a/plugins/facet/org.eclipse.papyrus.emf.facet.util.emf.catalog/src/org/eclipse/papyrus/emf/facet/util/emf/catalog/CatalogSet.java
+++ b/plugins/facet/org.eclipse.papyrus.emf.facet.util.emf.catalog/src/org/eclipse/papyrus/emf/facet/util/emf/catalog/CatalogSet.java
@@ -11,7 +11,7 @@
* Nicolas Guyomar (Mia-Software) - Implementation
*
*/
-package org.eclipse.emf.facet.util.emf.catalog;
+package org.eclipse.papyrus.emf.facet.util.emf.catalog;
import org.eclipse.emf.common.util.EList;
@@ -29,18 +29,18 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.emf.facet.util.emf.catalog.CatalogSet#getCatalogs <em>Catalogs</em>}</li>
+ * <li>{@link org.eclipse.papyrus.emf.facet.util.emf.catalog.CatalogSet#getCatalogs <em>Catalogs</em>}</li>
* </ul>
* </p>
*
- * @see org.eclipse.emf.facet.util.emf.catalog.CatalogPackage#getCatalogSet()
+ * @see org.eclipse.papyrus.emf.facet.util.emf.catalog.CatalogPackage#getCatalogSet()
* @model
* @generated
*/
public interface CatalogSet extends EObject {
/**
* Returns the value of the '<em><b>Catalogs</b></em>' containment reference list.
* The list contents are of type {@link org.eclipse.emf.facet.util.emf.catalog.Catalog}.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Catalogs</em>' containment reference list isn't clear,
@@ -51,7 +51,7 @@ public interface CatalogSet extends EObject {
* The "catalogs" reference references all the EMF Facet Catalog catalogs contained by a CatalogSet
* <!-- end-model-doc -->
* @return the value of the '<em>Catalogs</em>' containment reference list.
- * @see org.eclipse.emf.facet.util.emf.catalog.CatalogPackage#getCatalogSet_Catalogs()
+ * @see org.eclipse.papyrus.emf.facet.util.emf.catalog.CatalogPackage#getCatalogSet_Catalogs()
* @model containment="true"
* @generated
*/
@@ -29,18 +29,18 @@ import org.eclipse.emf.ecore.EObject;
/**
* Returns the value of the '<em><b>Catalogs</b></em>' containment reference list.
- * The list contents are of type {@link org.eclipse.emf.facet.util.emf.catalog.Catalog}.
+ * The list contents are of type {@link org.eclipse.papyrus.emf.facet.util.emf.catalog.Catalog}.
* <!-- begin-user-doc -->
* <p>

Back to the top